==> stonage-0.0.2.tar.gz: stonage-0.0.2/editor/main.c <==

#if defined(HAVE_CONFIG_H)
# include "config.h"
#endif

#include <glib.h>
#include <gtk/gtk.h>
#include <sys/types.h>
#include <libintl.h>
#include <locale.h>
#include "trace.h"
#include "square.h"

#define _(chaine) gettext(chaine)

#define DEFAULT_MAP_WIDTH  20
#define DEFAULT_MAP_HEIGHT 16


struct square_info
{
  GtkWidget *window;
  int        num;
  GList     *squares; /* Type of t_square */
};

struct map_info
{
  GtkWidget *window;
  int sizex;
  int sizey;
  int *map;
};

struct properties_info
{
  GtkWidget *window;
  GtkList   *properties;

};


struct square_info *create_square_window(const char *path);
struct map_info *create_map_window(void);
struct properties_info *create_properties_window(void);

int main(int argc, char **argv)
{
  struct map_info *map_info;
  struct square_info *square_info;
  struct properties_info *properties_info;

  gtk_init(&argc, &argv);
  gdk_rgb_init();

#ifdef ENABLE_NLS
  setlocale (LC_ALL, "");
  bindtextdomain (PACKAGE, LOCALEDIR);
  textdomain (PACKAGE);
#endif

  square_info=create_square_window(STONAGE_DATA_DIR);
  map_info=create_map_window();
  properties_info=create_properties_window();

  gtk_widget_show(square_info->window);
  gtk_widget_show(map_info->window);
  gtk_widget_show(properties_info->window);

  gtk_main();

  return 0;
}

void quit_editor_cb( GtkWidget *widget, gpointer   data )
{
  gtk_main_quit();
}



/*
 *
 * Create a window who contains all differents graphics squares
 *
 */
struct square_info *create_square_window(const char *datadir)
{
  GtkWidget *window, *scroll, *table;
  GList *pix;
  int n,i;
  struct square_info *info;

  /* Create a new window and a new structure */
  info = g_new0(struct square_info,1);
  
  /* Create the scrolled window */
  info->window = window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_signal_connect (GTK_OBJECT (window), "destroy",
      GTK_SIGNAL_FUNC (quit_editor_cb), NULL);

  scroll = gtk_scrolled_window_new(NULL,NULL);
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
      GTK_POLICY_AUTOMATIC,GTK_POLICY_ALWAYS);
  gtk_container_add(GTK_CONTAINER(window),scroll);
  gtk_widget_show(scroll);

  n = Square_Load_All(&info->squares);
  trace("nb d'images: %d\n",n);

  /* create two colums of squares */
  table = gtk_table_new (2, (n&1?(n+1)>>1:n>>1), FALSE);

  //gtk_table_set_row_spacings (GTK_TABLE (table), 10);
  //gtk_table_set_col_spacings (GTK_TABLE (table), 10);

  /* pack the table into the scrolled window */
  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW (scroll), table);
  gtk_widget_show(table);
  
  for (i=0, pix=info->squares ; i<n ; i++, pix=pix->next)
   {
     GtkWidget *pixmap, *button;
     struct t_square *s = (struct t_square *)pix->data;

     pixmap = s->pixmap;

     gtk_widget_show(pixmap);
     button = gtk_button_new();
     gtk_container_add (GTK_CONTAINER(button), pixmap);
     gtk_widget_show(button);
     //gtk_signal_connect( GTK_OBJECT(button), "clicked",
     //	   GTK_SIGNAL_FUNC(button_clicked), NULL );
     gtk_table_attach_defaults (GTK_TABLE (table), button,
	 i&1, (i&1)+1, (i/2), (i/2)+1);
   }

  gtk_widget_show(table);

  gtk_widget_set_usize(GTK_WIDGET(scroll),100,240);
  return info;
}

struct map_info *create_map_window(void)
{
  GtkWidget *window, *scroll, *table;
  

  struct map_info *info;

  info = g_new0(struct map_info,1);
  info->sizex = DEFAULT_MAP_WIDTH;
  info->sizey = DEFAULT_MAP_HEIGHT;
  info->map = g_new0(int,info->sizex*info->sizey);

  info->window = window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_signal_connect (GTK_OBJECT (window), "destroy",
      GTK_SIGNAL_FUNC (quit_editor_cb), NULL);

  scroll = gtk_scrolled_window_new(NULL,NULL);
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
      GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
  gtk_container_add(GTK_CONTAINER(window),scroll);
  gtk_widget_show(scroll);

  table = gtk_table_new (info->sizex, info->sizey, FALSE);

  gtk_widget_show(table);

  return info;
}



struct properties_info *create_properties_window(void)
{
  GtkWidget *window, *vbox, *hbox, *widget, *scrolledwindow;
  GtkList *list;
  GtkObject *adj;
  struct properties_info *info;
  int i;

  info = g_new0(struct properties_info,1);

  info->window = window = gtk_window_new(GTK_WINDOW_TOPLEVEL);

  vbox = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER(window), vbox);
  
  /*****************************************************
   *
   *****************************************************/

  hbox = gtk_hbox_new (FALSE, 0);
  gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);

  widget = gtk_label_new (_("delay (ms)"));
  gtk_box_pack_start (GTK_BOX(hbox), hbox, FALSE, FALSE, 0);

  adj = gtk_adjustment_new (1, 0, 500, 1, 10, 10);
  widget = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 1, 0);
  gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);


  /*****************************************************
   *
   *****************************************************/

  widget = gtk_label_new (_("Properties"));
  gtk_box_pack_start (GTK_BOX(vbox), widget, FALSE, FALSE, 0);

  scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
  //gtk_widget_set_usize ((GtkWidget *)scrolledwindow, 260, 200);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
      GTK_POLICY_AUTOMATIC,
      GTK_POLICY_ALWAYS);
  gtk_box_pack_start (GTK_BOX (vbox), scrolledwindow, TRUE, TRUE, 0);
  gtk_widget_show(scrolledwindow);

  info->properties = list = (GtkList *)gtk_list_new();
  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW (scrolledwindow), (GtkWidget *)list);
  gtk_list_set_selection_mode (list, GTK_SELECTION_MULTIPLE);
  gtk_widget_show(GTK_WIDGET(list));

  //gtk_signal_connect (GTK_OBJECT (list), "selection-changed",
  //    GTK_SIGNAL_FUNC (on_selection_changed_account),info);

  i=0;
  while (square_properties_text2enum[i].text)
   {
     GtkWidget *item;

     item = gtk_list_item_new_with_label (square_properties_text2enum[i].text);
     gtk_object_set_user_data(GTK_OBJECT(item), (gpointer)i);
     gtk_widget_show(item);
     i++;
   }


  gtk_widget_show(list);
  /*****************************************************
   *
   *****************************************************/

  return info;
}

==> stonage-0.0.3.tar.gz: stonage-0.0.3/editor/main.c <==
/*
 * Stonage: a puzzle game
 * Copyright (C) 2001 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#if defined(HAVE_CONFIG_H)
# include "config.h"
#endif

#include <glib.h>
#include <sys/types.h>
#include <libintl.h>
#include <locale.h>
#include "trace.h"
#include "square.h"

#include <gtk/gtkwidget.h>
#include <gtk/gtklist.h>
#include <gtk/gtkmain.h>
#include <gtk/gtktable.h>
#include <gtk/gtkvbox.h>
#include <gtk/gtkhbox.h>
#include <gtk/gtkwindow.h>
#include <gtk/gtksignal.h>
#include <gtk/gtkscrolledwindow.h>
#include <gtk/gtklabel.h>
#include <gtk/gtkbutton.h>
#include <gtk/gtkspinbutton.h>

#define _(chaine) gettext(chaine)

#define DEFAULT_MAP_WIDTH  20
#define DEFAULT_MAP_HEIGHT 16


struct square_info
{
  GtkWidget *window;
  int        num;
  GList     *squares; /* Type of t_square */
};

struct map_info
{
  GtkWidget *window;
  int sizex;
  int sizey;
  int *map;
};

struct properties_info
{
  GtkWidget *window;
  GtkList   *properties;

};


struct square_info *create_square_window(const char *path);
struct map_info *create_map_window(void);
struct properties_info *create_properties_window(void);

int main(int argc, char **argv)
{
  struct map_info *map_info;
  struct square_info *square_info;
  struct properties_info *properties_info;

  gtk_init(&argc, &argv);
  gdk_rgb_init();

#ifdef ENABLE_NLS
  setlocale (LC_ALL, "");
  bindtextdomain (PACKAGE, LOCALEDIR);
  textdomain (PACKAGE);
#endif

  square_info=create_square_window(STONAGE_DATA_DIR);
  map_info=create_map_window();
  properties_info=create_properties_window();

  gtk_widget_show(square_info->window);
  gtk_widget_show(map_info->window);
  gtk_widget_show(properties_info->window);

  gtk_main();

  return 0;
}

void quit_editor_cb( GtkWidget *widget, gpointer   data )
{
  gtk_main_quit();
}



/*
 *
 * Create a window who contains all differents graphics squares
 *
 */
struct square_info *create_square_window(const char *datadir)
{
  GtkWidget *window, *scroll, *table;
  GList *pix;
  int n,i;
  struct square_info *info;

  /* Create a new window and a new structure */
  info = g_new0(struct square_info,1);
  
  /* Create the scrolled window */
  info->window = window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_signal_connect (GTK_OBJECT (window), "destroy",
      GTK_SIGNAL_FUNC (quit_editor_cb), NULL);

  scroll = gtk_scrolled_window_new(NULL,NULL);
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
      GTK_POLICY_AUTOMATIC,GTK_POLICY_ALWAYS);
  gtk_container_add(GTK_CONTAINER(window),scroll);
  gtk_widget_show(scroll);

  n = Square_Load_All(&info->squares);
  trace("nb d'images: %d\n",n);

  /* create two colums of squares */
  table = gtk_table_new (2, (n&1?(n+1)>>1:n>>1), FALSE);

  //gtk_table_set_row_spacings (GTK_TABLE (table), 10);
  //gtk_table_set_col_spacings (GTK_TABLE (table), 10);

  /* pack the table into the scrolled window */
  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW (scroll), table);
  gtk_widget_show(table);
  
  for (i=0, pix=info->squares ; i<n ; i++, pix=pix->next)
   {
     GtkWidget *pixmap, *button;
     struct t_square *s = (struct t_square *)pix->data;

     pixmap = s->pixmap;

     gtk_widget_show(pixmap);
     button = gtk_button_new();
     gtk_container_add (GTK_CONTAINER(button), pixmap);
     gtk_widget_show(button);
     //gtk_signal_connect( GTK_OBJECT(button), "clicked",
     //	   GTK_SIGNAL_FUNC(button_clicked), NULL );
     gtk_table_attach_defaults (GTK_TABLE (table), button,
	 i&1, (i&1)+1, (i/2), (i/2)+1);
   }

  gtk_widget_show(table);

  gtk_widget_set_usize(GTK_WIDGET(scroll),100,240);
  return info;
}

struct map_info *create_map_window(void)
{
  GtkWidget *window, *scroll, *table;
  

  struct map_info *info;

  info = g_new0(struct map_info,1);
  info->sizex = DEFAULT_MAP_WIDTH;
  info->sizey = DEFAULT_MAP_HEIGHT;
  info->map = g_new0(int,info->sizex*info->sizey);

  info->window = window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_signal_connect (GTK_OBJECT (window), "destroy",
      GTK_SIGNAL_FUNC (quit_editor_cb), NULL);

  scroll = gtk_scrolled_window_new(NULL,NULL);
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
      GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
  gtk_container_add(GTK_CONTAINER(window),scroll);
  gtk_widget_show(scroll);

  table = gtk_table_new (info->sizex, info->sizey, FALSE);

  gtk_widget_show(table);

  return info;
}



struct properties_info *create_properties_window(void)
{
  GtkWidget *window, *vbox, *hbox, *widget, *scrolledwindow;
  GtkList *list;
  GtkObject *adj;
  GList *square_properties;
  struct properties_info *info;
  int i;

  info = g_new0(struct properties_info,1);

  info->window = window = gtk_window_new(GTK_WINDOW_TOPLEVEL);

  vbox = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER(window), vbox);
  
  /*****************************************************
   *
   *****************************************************/

  hbox = gtk_hbox_new (FALSE, 0);
  gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);

  widget = gtk_label_new (_("delay (ms)"));
  gtk_box_pack_start (GTK_BOX(hbox), widget, FALSE, FALSE, 0);

  adj = gtk_adjustment_new (1, 0, 500, 1, 10, 10);
  widget = gtk_spin_button_new (GTK_ADJUSTMENT (adj), 1, 0);
  gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);

  /*****************************************************
   *
   *****************************************************/

  widget = gtk_label_new (_("Properties"));
  gtk_box_pack_start (GTK_BOX(vbox), widget, FALSE, FALSE, 0);

  scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
  //gtk_widget_set_usize ((GtkWidget *)scrolledwindow, 260, 200);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
      GTK_POLICY_AUTOMATIC,
      GTK_POLICY_ALWAYS);
  gtk_box_pack_start (GTK_BOX (vbox), scrolledwindow, TRUE, TRUE, 0);

  info->properties = list = (GtkList *)gtk_list_new();
  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW (scrolledwindow), (GtkWidget *)list);
  gtk_list_set_selection_mode (list, GTK_SELECTION_MULTIPLE);

  //gtk_signal_connect (GTK_OBJECT (list), "selection-changed",
  //    GTK_SIGNAL_FUNC (on_selection_changed_account),info);

  i=0; square_properties=NULL;
  while (square_properties_text2enum[i].text)
   {
     GtkWidget *item;

     item = gtk_list_item_new_with_label (square_properties_text2enum[i].text);
     gtk_object_set_user_data(GTK_OBJECT(item), (gpointer)i);
     gtk_widget_show(item);
     square_properties = g_list_append(square_properties, item);
     i++;
   }
  gtk_list_append_items(GTK_LIST(list),square_properties);
  //g_list_free(square_properties);


  gtk_widget_show_all(vbox);
  /*****************************************************
   *
   *****************************************************/

  return info;
}
